# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Version(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "notes",
            "data",
            "createdBy",
            "organization",
            "project",
            "_id",
            "extId",
            "tag",
            "branch",
            "isFavourite",
            "status",
        }
        
        class properties:
            _id = schemas.StrSchema
            extId = schemas.StrSchema
            createdBy = schemas.StrSchema
            organization = schemas.StrSchema
            project = schemas.StrSchema
            branch = schemas.StrSchema
            tag = schemas.StrSchema
        
            @staticmethod
            def data() -> typing.Type['ModelGraph']:
                return ModelGraph
            createdAt = schemas.DateTimeSchema
            notes = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "visible": "VISIBLE",
                        "trash": "TRASH",
                    }
                
                @schemas.classproperty
                def VISIBLE(cls):
                    return cls("visible")
                
                @schemas.classproperty
                def TRASH(cls):
                    return cls("trash")
            isFavourite = schemas.BoolSchema
            __annotations__ = {
                "_id": _id,
                "extId": extId,
                "createdBy": createdBy,
                "organization": organization,
                "project": project,
                "branch": branch,
                "tag": tag,
                "data": data,
                "createdAt": createdAt,
                "notes": notes,
                "status": status,
                "isFavourite": isFavourite,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    notes: MetaOapg.properties.notes
    data: 'ModelGraph'
    createdBy: MetaOapg.properties.createdBy
    organization: MetaOapg.properties.organization
    project: MetaOapg.properties.project
    _id: MetaOapg.properties._id
    extId: MetaOapg.properties.extId
    tag: MetaOapg.properties.tag
    branch: MetaOapg.properties.branch
    isFavourite: MetaOapg.properties.isFavourite
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> 'ModelGraph': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["project"]) -> MetaOapg.properties.project: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extId"]) -> MetaOapg.properties.extId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["branch"]) -> MetaOapg.properties.branch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isFavourite"]) -> MetaOapg.properties.isFavourite: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["notes"], typing_extensions.Literal["data"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["organization"], typing_extensions.Literal["project"], typing_extensions.Literal["_id"], typing_extensions.Literal["extId"], typing_extensions.Literal["tag"], typing_extensions.Literal["branch"], typing_extensions.Literal["isFavourite"], typing_extensions.Literal["status"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> 'ModelGraph': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["project"]) -> MetaOapg.properties.project: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extId"]) -> MetaOapg.properties.extId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["branch"]) -> MetaOapg.properties.branch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isFavourite"]) -> MetaOapg.properties.isFavourite: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["notes"], typing_extensions.Literal["data"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["organization"], typing_extensions.Literal["project"], typing_extensions.Literal["_id"], typing_extensions.Literal["extId"], typing_extensions.Literal["tag"], typing_extensions.Literal["branch"], typing_extensions.Literal["isFavourite"], typing_extensions.Literal["status"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        notes: typing.Union[MetaOapg.properties.notes, str, ],
        data: 'ModelGraph',
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, ],
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        project: typing.Union[MetaOapg.properties.project, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        extId: typing.Union[MetaOapg.properties.extId, str, ],
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        branch: typing.Union[MetaOapg.properties.branch, str, ],
        isFavourite: typing.Union[MetaOapg.properties.isFavourite, bool, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Version':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            notes=notes,
            data=data,
            createdBy=createdBy,
            organization=organization,
            project=project,
            _id=_id,
            extId=extId,
            tag=tag,
            branch=branch,
            isFavourite=isFavourite,
            status=status,
            _configuration=_configuration,
        )

from openapi_client.model.model_graph import ModelGraph



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class MultiThresholdConfusionMatrixParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "modelExtIds",
            "customMetricName",
        }
        
        class properties:
            
            
            class modelExtIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'modelExtIds':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            customMetricName = schemas.StrSchema
            verticalSplit = schemas.StrSchema
            horizontalSplit = schemas.StrSchema
            
            
            class filters(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ESFilter']:
                        return ESFilter
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ESFilter'], typing.List['ESFilter']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'filters':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ESFilter':
                    return super().__getitem__(i)
            __annotations__ = {
                "modelExtIds": modelExtIds,
                "customMetricName": customMetricName,
                "verticalSplit": verticalSplit,
                "horizontalSplit": horizontalSplit,
                "filters": filters,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    modelExtIds: MetaOapg.properties.modelExtIds
    customMetricName: MetaOapg.properties.customMetricName
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customMetricName"]) -> MetaOapg.properties.customMetricName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verticalSplit"]) -> MetaOapg.properties.verticalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["horizontalSplit"]) -> MetaOapg.properties.horizontalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["filters"]) -> MetaOapg.properties.filters: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["customMetricName"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["filters"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customMetricName"]) -> MetaOapg.properties.customMetricName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verticalSplit"]) -> typing.Union[MetaOapg.properties.verticalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["horizontalSplit"]) -> typing.Union[MetaOapg.properties.horizontalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["filters"]) -> typing.Union[MetaOapg.properties.filters, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["customMetricName"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["filters"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        modelExtIds: typing.Union[MetaOapg.properties.modelExtIds, list, tuple, ],
        customMetricName: typing.Union[MetaOapg.properties.customMetricName, str, ],
        verticalSplit: typing.Union[MetaOapg.properties.verticalSplit, str, schemas.Unset] = schemas.unset,
        horizontalSplit: typing.Union[MetaOapg.properties.horizontalSplit, str, schemas.Unset] = schemas.unset,
        filters: typing.Union[MetaOapg.properties.filters, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MultiThresholdConfusionMatrixParams':
        return super().__new__(
            cls,
            *args,
            modelExtIds=modelExtIds,
            customMetricName=customMetricName,
            verticalSplit=verticalSplit,
            horizontalSplit=horizontalSplit,
            filters=filters,
            _configuration=_configuration,
        )

from openapi_client.model.es_filter import ESFilter



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Insight(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "organizationId",
            "createdAt",
            "data",
            "createdBy",
            "modelId",
            "modelEpoch",
            "visualizationUuid",
            "_id",
            "modelExtId",
            "updatedAt",
        }
        
        class properties:
            _id = schemas.StrSchema
            modelId = schemas.StrSchema
            modelEpoch = schemas.Float64Schema
            modelExtId = schemas.StrSchema
            organizationId = schemas.StrSchema
            createdBy = schemas.StrSchema
            createdAt = schemas.DateTimeSchema
            updatedAt = schemas.DateTimeSchema
            visualizationUuid = schemas.StrSchema
        
            @staticmethod
            def data() -> typing.Type['InsightType']:
                return InsightType
            __annotations__ = {
                "_id": _id,
                "modelId": modelId,
                "modelEpoch": modelEpoch,
                "modelExtId": modelExtId,
                "organizationId": organizationId,
                "createdBy": createdBy,
                "createdAt": createdAt,
                "updatedAt": updatedAt,
                "visualizationUuid": visualizationUuid,
                "data": data,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    organizationId: MetaOapg.properties.organizationId
    createdAt: MetaOapg.properties.createdAt
    data: 'InsightType'
    createdBy: MetaOapg.properties.createdBy
    modelId: MetaOapg.properties.modelId
    modelEpoch: MetaOapg.properties.modelEpoch
    visualizationUuid: MetaOapg.properties.visualizationUuid
    _id: MetaOapg.properties._id
    modelExtId: MetaOapg.properties.modelExtId
    updatedAt: MetaOapg.properties.updatedAt
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organizationId"]) -> MetaOapg.properties.organizationId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> 'InsightType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelEpoch"]) -> MetaOapg.properties.modelEpoch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visualizationUuid"]) -> MetaOapg.properties.visualizationUuid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelExtId"]) -> MetaOapg.properties.modelExtId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updatedAt"]) -> MetaOapg.properties.updatedAt: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["organizationId"], typing_extensions.Literal["createdAt"], typing_extensions.Literal["data"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["modelId"], typing_extensions.Literal["modelEpoch"], typing_extensions.Literal["visualizationUuid"], typing_extensions.Literal["_id"], typing_extensions.Literal["modelExtId"], typing_extensions.Literal["updatedAt"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organizationId"]) -> MetaOapg.properties.organizationId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> 'InsightType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelEpoch"]) -> MetaOapg.properties.modelEpoch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visualizationUuid"]) -> MetaOapg.properties.visualizationUuid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelExtId"]) -> MetaOapg.properties.modelExtId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updatedAt"]) -> MetaOapg.properties.updatedAt: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["organizationId"], typing_extensions.Literal["createdAt"], typing_extensions.Literal["data"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["modelId"], typing_extensions.Literal["modelEpoch"], typing_extensions.Literal["visualizationUuid"], typing_extensions.Literal["_id"], typing_extensions.Literal["modelExtId"], typing_extensions.Literal["updatedAt"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        organizationId: typing.Union[MetaOapg.properties.organizationId, str, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        data: 'InsightType',
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, ],
        modelId: typing.Union[MetaOapg.properties.modelId, str, ],
        modelEpoch: typing.Union[MetaOapg.properties.modelEpoch, decimal.Decimal, int, float, ],
        visualizationUuid: typing.Union[MetaOapg.properties.visualizationUuid, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        modelExtId: typing.Union[MetaOapg.properties.modelExtId, str, ],
        updatedAt: typing.Union[MetaOapg.properties.updatedAt, str, datetime, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Insight':
        return super().__new__(
            cls,
            *args,
            organizationId=organizationId,
            createdAt=createdAt,
            data=data,
            createdBy=createdBy,
            modelId=modelId,
            modelEpoch=modelEpoch,
            visualizationUuid=visualizationUuid,
            _id=_id,
            modelExtId=modelExtId,
            updatedAt=updatedAt,
            _configuration=_configuration,
        )

from openapi_client.model.insight_type import InsightType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Model(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "modelName",
            "organization",
            "hasNext",
            "_id",
            "parentModels",
            "type",
            "targetJob",
        }
        
        class properties:
            _id = schemas.StrSchema
            modelName = schemas.StrSchema
        
            @staticmethod
            def type() -> typing.Type['ModelType']:
                return ModelType
            createdAt = schemas.DateTimeSchema
            targetJob = schemas.StrSchema
            
            
            class parentModels(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'parentModels':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            organization = schemas.StrSchema
            
            
            class hasNext(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'hasNext':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            extId = schemas.StrSchema
            createdBy = schemas.StrSchema
            
            
            class hash(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'hash':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def trainingParams() -> typing.Type['TrainingParams']:
                return TrainingParams
            
            
            class savedData(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ModelSaveData']:
                        return ModelSaveData
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ModelSaveData'], typing.List['ModelSaveData']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'savedData':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ModelSaveData':
                    return super().__getitem__(i)
            __annotations__ = {
                "_id": _id,
                "modelName": modelName,
                "type": type,
                "createdAt": createdAt,
                "targetJob": targetJob,
                "parentModels": parentModels,
                "organization": organization,
                "hasNext": hasNext,
                "extId": extId,
                "createdBy": createdBy,
                "hash": hash,
                "trainingParams": trainingParams,
                "savedData": savedData,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    modelName: MetaOapg.properties.modelName
    organization: MetaOapg.properties.organization
    hasNext: MetaOapg.properties.hasNext
    _id: MetaOapg.properties._id
    parentModels: MetaOapg.properties.parentModels
    type: 'ModelType'
    targetJob: MetaOapg.properties.targetJob
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hasNext"]) -> MetaOapg.properties.hasNext: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parentModels"]) -> MetaOapg.properties.parentModels: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'ModelType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["targetJob"]) -> MetaOapg.properties.targetJob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extId"]) -> MetaOapg.properties.extId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trainingParams"]) -> 'TrainingParams': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["savedData"]) -> MetaOapg.properties.savedData: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["modelName"], typing_extensions.Literal["organization"], typing_extensions.Literal["hasNext"], typing_extensions.Literal["_id"], typing_extensions.Literal["parentModels"], typing_extensions.Literal["type"], typing_extensions.Literal["targetJob"], typing_extensions.Literal["extId"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["hash"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["savedData"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hasNext"]) -> MetaOapg.properties.hasNext: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parentModels"]) -> MetaOapg.properties.parentModels: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'ModelType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["targetJob"]) -> MetaOapg.properties.targetJob: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extId"]) -> typing.Union[MetaOapg.properties.extId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> typing.Union[MetaOapg.properties.createdBy, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> typing.Union[MetaOapg.properties.hash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trainingParams"]) -> typing.Union['TrainingParams', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["savedData"]) -> typing.Union[MetaOapg.properties.savedData, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["modelName"], typing_extensions.Literal["organization"], typing_extensions.Literal["hasNext"], typing_extensions.Literal["_id"], typing_extensions.Literal["parentModels"], typing_extensions.Literal["type"], typing_extensions.Literal["targetJob"], typing_extensions.Literal["extId"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["hash"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["savedData"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        modelName: typing.Union[MetaOapg.properties.modelName, str, ],
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        hasNext: typing.Union[MetaOapg.properties.hasNext, None, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        parentModels: typing.Union[MetaOapg.properties.parentModels, list, tuple, ],
        type: 'ModelType',
        targetJob: typing.Union[MetaOapg.properties.targetJob, str, ],
        extId: typing.Union[MetaOapg.properties.extId, str, schemas.Unset] = schemas.unset,
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, schemas.Unset] = schemas.unset,
        hash: typing.Union[MetaOapg.properties.hash, None, str, schemas.Unset] = schemas.unset,
        trainingParams: typing.Union['TrainingParams', schemas.Unset] = schemas.unset,
        savedData: typing.Union[MetaOapg.properties.savedData, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Model':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            modelName=modelName,
            organization=organization,
            hasNext=hasNext,
            _id=_id,
            parentModels=parentModels,
            type=type,
            targetJob=targetJob,
            extId=extId,
            createdBy=createdBy,
            hash=hash,
            trainingParams=trainingParams,
            savedData=savedData,
            _configuration=_configuration,
        )

from openapi_client.model.model_save_data import ModelSaveData
from openapi_client.model.model_type import ModelType
from openapi_client.model.training_params import TrainingParams



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_client.model.action_assignment_element import ActionAssignmentElement
from openapi_client.model.action_comment_element import ActionCommentElement
from openapi_client.model.action_tag_element import ActionTagElement
from openapi_client.model.activation_params import ActivationParams
from openapi_client.model.add_dashboard_params import AddDashboardParams
from openapi_client.model.add_dashboard_response import AddDashboardResponse
from openapi_client.model.add_dataset_response import AddDatasetResponse
from openapi_client.model.add_export_model_job_params import AddExportModelJobParams
from openapi_client.model.add_issue_params import AddIssueParams
from openapi_client.model.add_project_params import AddProjectParams
from openapi_client.model.add_project_response import AddProjectResponse
from openapi_client.model.add_secret_manager_params import AddSecretManagerParams
from openapi_client.model.add_secret_manager_response import AddSecretManagerResponse
from openapi_client.model.add_version_params import AddVersionParams
from openapi_client.model.add_version_response import AddVersionResponse
from openapi_client.model.aggregation_method import AggregationMethod
from openapi_client.model.aggregations import Aggregations
from openapi_client.model.all_models_test_results import AllModelsTestResults
from openapi_client.model.analyze_params import AnalyzeParams
from openapi_client.model.analyze_type_enum import AnalyzeTypeEnum
from openapi_client.model.axis_type import AxisType
from openapi_client.model.b_box_image_data import BBoxImageData
from openapi_client.model.b_box_image_scatter_label import BBoxImageScatterLabel
from openapi_client.model.b_box_image_viz import BBoxImageViz
from openapi_client.model.basic_visualization_info import BasicVisualizationInfo
from openapi_client.model.bounding_box import BoundingBox
from openapi_client.model.bucket_aggregation import BucketAggregation
from openapi_client.model.chart_response import ChartResponse
from openapi_client.model.client_filter_params import ClientFilterParams
from openapi_client.model.cluster_insight import ClusterInsight
from openapi_client.model.clusters import Clusters
from openapi_client.model.confusion_matrix_params import ConfusionMatrixParams
from openapi_client.model.confusion_metric_names_response import ConfusionMetricNamesResponse
from openapi_client.model.continue_train_params import ContinueTrainParams
from openapi_client.model.create_model_test_request import CreateModelTestRequest
from openapi_client.model.create_organization_request import CreateOrganizationRequest
from openapi_client.model.create_organization_response import CreateOrganizationResponse
from openapi_client.model.custom_layer_instance import CustomLayerInstance
from openapi_client.model.custom_message_data import CustomMessageData
from openapi_client.model.custom_message_data_params import CustomMessageDataParams
from openapi_client.model.custom_visualization_data import CustomVisualizationData
from openapi_client.model.custom_visualization_item import CustomVisualizationItem
from openapi_client.model.custom_visualization_type import CustomVisualizationType
from openapi_client.model.dashboard import Dashboard
from openapi_client.model.dashboard_item import DashboardItem
from openapi_client.model.data_distribution_type import DataDistributionType
from openapi_client.model.data_state_for_eval import DataStateForEval
from openapi_client.model.data_state_type import DataStateType
from openapi_client.model.data_type_enum import DataTypeEnum
from openapi_client.model.dataset import Dataset
from openapi_client.model.dataset_access import DatasetAccess
from openapi_client.model.dataset_input_instance import DatasetInputInstance
from openapi_client.model.dataset_message_params import DatasetMessageParams
from openapi_client.model.dataset_metadata import DatasetMetadata
from openapi_client.model.dataset_metadata_instance import DatasetMetadataInstance
from openapi_client.model.dataset_metadata_type import DatasetMetadataType
from openapi_client.model.dataset_output_instance import DatasetOutputInstance
from openapi_client.model.dataset_parse_request_params import DatasetParseRequestParams
from openapi_client.model.dataset_preprocess import DatasetPreprocess
from openapi_client.model.dataset_setup import DatasetSetup
from openapi_client.model.dataset_setup_status import DatasetSetupStatus
from openapi_client.model.dataset_test_result_payload import DatasetTestResultPayload
from openapi_client.model.dataset_version import DatasetVersion
from openapi_client.model.delete_dashboard_params import DeleteDashboardParams
from openapi_client.model.delete_issue_params import DeleteIssueParams
from openapi_client.model.delete_model_params import DeleteModelParams
from openapi_client.model.delete_model_test_request import DeleteModelTestRequest
from openapi_client.model.delete_organization_request import DeleteOrganizationRequest
from openapi_client.model.delete_project_params import DeleteProjectParams
from openapi_client.model.delete_user_by_id_request import DeleteUserByIdRequest
from openapi_client.model.delete_version_params import DeleteVersionParams
from openapi_client.model.delete_visualizations_params import DeleteVisualizationsParams
from openapi_client.model.demo import Demo
from openapi_client.model.domain import Domain
from openapi_client.model.domain_max import DomainMax
from openapi_client.model.domain_min import DomainMin
from openapi_client.model.es_filter import ESFilter
from openapi_client.model.es_filter_value import ESFilterValue
from openapi_client.model.early_stop_params import EarlyStopParams
from openapi_client.model.es_batch_aggregation_type import EsBatchAggregationType
from openapi_client.model.evaluate_params import EvaluateParams
from openapi_client.model.export_model_params import ExportModelParams
from openapi_client.model.export_model_type_enum import ExportModelTypeEnum
from openapi_client.model.exported_model_job_ui import ExportedModelJobUi
from openapi_client.model.extend_trial_params import ExtendTrialParams
from openapi_client.model.extend_trial_response import ExtendTrialResponse
from openapi_client.model.external_import_model_storage import ExternalImportModelStorage
from openapi_client.model.external_import_model_storage_response import ExternalImportModelStorageResponse
from openapi_client.model.feature_importance import FeatureImportance
from openapi_client.model.feature_importance_item import FeatureImportanceItem
from openapi_client.model.filter_operator_type import FilterOperatorType
from openapi_client.model.general_message_params import GeneralMessageParams
from openapi_client.model.generic_data_query_params import GenericDataQueryParams
from openapi_client.model.generic_data_response import GenericDataResponse
from openapi_client.model.get_all_project_model_tests_request import GetAllProjectModelTestsRequest
from openapi_client.model.get_balanced_accuracy_params import GetBalancedAccuracyParams
from openapi_client.model.get_confusion_metric_names_object import GetConfusionMetricNamesObject
from openapi_client.model.get_current_project_version_params import GetCurrentProjectVersionParams
from openapi_client.model.get_current_project_version_response import GetCurrentProjectVersionResponse
from openapi_client.model.get_dashboard_params import GetDashboardParams
from openapi_client.model.get_dashboard_response import GetDashboardResponse
from openapi_client.model.get_dashlet_fields_response import GetDashletFieldsResponse
from openapi_client.model.get_dataset_version_params import GetDatasetVersionParams
from openapi_client.model.get_dataset_version_response import GetDatasetVersionResponse
from openapi_client.model.get_dataset_versions_params import GetDatasetVersionsParams
from openapi_client.model.get_dataset_versions_response import GetDatasetVersionsResponse
from openapi_client.model.get_datasets_response import GetDatasetsResponse
from openapi_client.model.get_demos_response import GetDemosResponse
from openapi_client.model.get_exported_model_jobs_params import GetExportedModelJobsParams
from openapi_client.model.get_exported_model_jobs_response import GetExportedModelJobsResponse
from openapi_client.model.get_f1_score_params import GetF1ScoreParams
from openapi_client.model.get_jobs_params import GetJobsParams
from openapi_client.model.get_jobs_response import GetJobsResponse
from openapi_client.model.get_kibana_dashboards_response import GetKibanaDashboardsResponse
from openapi_client.model.get_kibana_dashlet_fields_response import GetKibanaDashletFieldsResponse
from openapi_client.model.get_latest_dataset_version_params import GetLatestDatasetVersionParams
from openapi_client.model.get_latest_dataset_version_response import GetLatestDatasetVersionResponse
from openapi_client.model.get_machine_types_response import GetMachineTypesResponse
from openapi_client.model.get_max_active_users_response import GetMaxActiveUsersResponse
from openapi_client.model.get_model_epoch_loss_params import GetModelEpochLossParams
from openapi_client.model.get_model_insights_params import GetModelInsightsParams
from openapi_client.model.get_model_insights_response import GetModelInsightsResponse
from openapi_client.model.get_model_test_results_request import GetModelTestResultsRequest
from openapi_client.model.get_model_visualizations_params import GetModelVisualizationsParams
from openapi_client.model.get_model_visualizations_response import GetModelVisualizationsResponse
from openapi_client.model.get_notifications_response import GetNotificationsResponse
from openapi_client.model.get_organization_jobs_params import GetOrganizationJobsParams
from openapi_client.model.get_organization_users_request import GetOrganizationUsersRequest
from openapi_client.model.get_organization_users_response import GetOrganizationUsersResponse
from openapi_client.model.get_organizations_response import GetOrganizationsResponse
from openapi_client.model.get_pr_curve_params import GetPrCurveParams
from openapi_client.model.get_project_dashboards_params import GetProjectDashboardsParams
from openapi_client.model.get_project_dashboards_response import GetProjectDashboardsResponse
from openapi_client.model.get_project_issues_params import GetProjectIssuesParams
from openapi_client.model.get_project_issues_response import GetProjectIssuesResponse
from openapi_client.model.get_project_slim_versions_response import GetProjectSlimVersionsResponse
from openapi_client.model.get_project_versions_params import GetProjectVersionsParams
from openapi_client.model.get_projects_response import GetProjectsResponse
from openapi_client.model.get_roc_params import GetRocParams
from openapi_client.model.get_secret_manager_list_response import GetSecretManagerListResponse
from openapi_client.model.get_single_issue_params import GetSingleIssueParams
from openapi_client.model.get_single_model_test_request import GetSingleModelTestRequest
from openapi_client.model.get_statistics_response import GetStatisticsResponse
from openapi_client.model.get_stored_exported_model_resource_url_params import GetStoredExportedModelResourceUrlParams
from openapi_client.model.get_stored_exported_model_resource_url_response import GetStoredExportedModelResourceUrlResponse
from openapi_client.model.get_stored_resource_url_params import GetStoredResourceUrlParams
from openapi_client.model.get_stored_resource_url_response import GetStoredResourceUrlResponse
from openapi_client.model.get_training_job_params import GetTrainingJobParams
from openapi_client.model.get_upload_signed_url_params import GetUploadSignedUrlParams
from openapi_client.model.get_visualization_params import GetVisualizationParams
from openapi_client.model.grads_analysis import GradsAnalysis
from openapi_client.model.grads_item import GradsItem
from openapi_client.model.graph_data import GraphData
from openapi_client.model.graph_scatter_label import GraphScatterLabel
from openapi_client.model.graph_viz import GraphViz
from openapi_client.model.health_check_response import HealthCheckResponse
from openapi_client.model.health_status import HealthStatus
from openapi_client.model.heatmap import Heatmap
from openapi_client.model.heatmap_charts_params import HeatmapChartsParams
from openapi_client.model.heatmap_type import HeatmapType
from openapi_client.model.horizontal_bar_data import HorizontalBarData
from openapi_client.model.horizontal_bar_scatter_label import HorizontalBarScatterLabel
from openapi_client.model.horizontal_bar_viz import HorizontalBarViz
from openapi_client.model.horizontal_charts import HorizontalCharts
from openapi_client.model.image_data import ImageData
from openapi_client.model.image_scatter_label import ImageScatterLabel
from openapi_client.model.image_viz import ImageViz
from openapi_client.model.import_demo_project_params import ImportDemoProjectParams
from openapi_client.model.import_demo_project_response import ImportDemoProjectResponse
from openapi_client.model.import_model_type import ImportModelType
from openapi_client.model.import_new_model_params import ImportNewModelParams
from openapi_client.model.insight import Insight
from openapi_client.model.insight_type import InsightType
from openapi_client.model.is_training_job_running_params import IsTrainingJobRunningParams
from openapi_client.model.is_training_job_running_response import IsTrainingJobRunningResponse
from openapi_client.model.issue import Issue
from openapi_client.model.issue_action import IssueAction
from openapi_client.model.issue_action_type import IssueActionType
from openapi_client.model.issue_activity import IssueActivity
from openapi_client.model.issue_status import IssueStatus
from openapi_client.model.job import Job
from openapi_client.model.job_message_params import JobMessageParams
from openapi_client.model.job_notification_base_context import JobNotificationBaseContext
from openapi_client.model.job_notification_context import JobNotificationContext
from openapi_client.model.job_notification_leep_script_context import JobNotificationLeepScriptContext
from openapi_client.model.job_notification_model_context import JobNotificationModelContext
from openapi_client.model.job_params import JobParams
from openapi_client.model.job_status import JobStatus
from openapi_client.model.job_type_enum import JobTypeEnum
from openapi_client.model.key_login_params import KeyLoginParams
from openapi_client.model.layout import Layout
from openapi_client.model.leap_data_type import LeapDataType
from openapi_client.model.line import Line
from openapi_client.model.load_model_params import LoadModelParams
from openapi_client.model.load_model_response import LoadModelResponse
from openapi_client.model.load_version_params import LoadVersionParams
from openapi_client.model.load_version_response import LoadVersionResponse
from openapi_client.model.login_params import LoginParams
from openapi_client.model.loss_message_params import LossMessageParams
from openapi_client.model.machine_type_option import MachineTypeOption
from openapi_client.model.mask_image_data import MaskImageData
from openapi_client.model.mask_image_scatter_label import MaskImageScatterLabel
from openapi_client.model.mask_text_data import MaskTextData
from openapi_client.model.message_level import MessageLevel
from openapi_client.model.metric import Metric
from openapi_client.model.metric_message_params import MetricMessageParams
from openapi_client.model.model import Model
from openapi_client.model.model_graph import ModelGraph
from openapi_client.model.model_hash_request_params import ModelHashRequestParams
from openapi_client.model.model_populated_job import ModelPopulatedJob
from openapi_client.model.model_save_data import ModelSaveData
from openapi_client.model.model_setup import ModelSetup
from openapi_client.model.model_test import ModelTest
from openapi_client.model.model_test_data import ModelTestData
from openapi_client.model.model_test_result import ModelTestResult
from openapi_client.model.model_test_result_error import ModelTestResultError
from openapi_client.model.model_test_result_not_found import ModelTestResultNotFound
from openapi_client.model.model_test_result_success import ModelTestResultSuccess
from openapi_client.model.model_type import ModelType
from openapi_client.model.model_version_id_request_params import ModelVersionIdRequestParams
from openapi_client.model.models_response import ModelsResponse
from openapi_client.model.modify_dataset_version_note_params import ModifyDatasetVersionNoteParams
from openapi_client.model.modify_dataset_version_note_response import ModifyDatasetVersionNoteResponse
from openapi_client.model.module import Module
from openapi_client.model.module_message_data import ModuleMessageData
from openapi_client.model.module_status import ModuleStatus
from openapi_client.model.module_status_all_modules import ModuleStatusAllModules
from openapi_client.model.monitored_module_type import MonitoredModuleType
from openapi_client.model.multi_charts_params import MultiChartsParams
from openapi_client.model.multi_charts_response import MultiChartsResponse
from openapi_client.model.multi_threshold_confusion_matrix_params import MultiThresholdConfusionMatrixParams
from openapi_client.model.new_dataset_params import NewDatasetParams
from openapi_client.model.node_message_params import NodeMessageParams
from openapi_client.model.node_type import NodeType
from openapi_client.model.notification import Notification
from openapi_client.model.number_or_string import NumberOrString
from openapi_client.model.operator_enum import OperatorEnum
from openapi_client.model.order_type import OrderType
from openapi_client.model.overfitting_insight import OverfittingInsight
from openapi_client.model.panel_layout import PanelLayout
from openapi_client.model.parse_dataset_response import ParseDatasetResponse
from openapi_client.model.partial_record_tour_page_tour_step_definition_array import PartialRecordTourPageTourStepDefinitionArray
from openapi_client.model.point import Point
from openapi_client.model.point_value_types import PointValueTypes
from openapi_client.model.pop_explore_info import PopExploreInfo
from openapi_client.model.population_exploration_params import PopulationExplorationParams
from openapi_client.model.prediction_type_instance import PredictionTypeInstance
from openapi_client.model.project import Project
from openapi_client.model.project_access import ProjectAccess
from openapi_client.model.project_status import ProjectStatus
from openapi_client.model.recent_models_response import RecentModelsResponse
from openapi_client.model.recent_organization_models_request_params import RecentOrganizationModelsRequestParams
from openapi_client.model.request_trial_metadata import RequestTrialMetadata
from openapi_client.model.request_trial_params import RequestTrialParams
from openapi_client.model.request_trial_response import RequestTrialResponse
from openapi_client.model.resend_activation_mail_params import ResendActivationMailParams
from openapi_client.model.resend_activation_mail_response import ResendActivationMailResponse
from openapi_client.model.reset_password_params import ResetPasswordParams
from openapi_client.model.reset_password_response import ResetPasswordResponse
from openapi_client.model.rotate_api_key_response import RotateApiKeyResponse
from openapi_client.model.sample_analysis_params import SampleAnalysisParams
from openapi_client.model.sample_analysis_viz import SampleAnalysisViz
from openapi_client.model.sample_identity import SampleIdentity
from openapi_client.model.sample_selection_info import SampleSelectionInfo
from openapi_client.model.sample_selection_params import SampleSelectionParams
from openapi_client.model.sample_visualization_info import SampleVisualizationInfo
from openapi_client.model.save_analyzer_layout_params import SaveAnalyzerLayoutParams
from openapi_client.model.save_dataset_setup_response import SaveDatasetSetupResponse
from openapi_client.model.save_dataset_version_params import SaveDatasetVersionParams
from openapi_client.model.scatter_filter import ScatterFilter
from openapi_client.model.scatter_insight_type import ScatterInsightType
from openapi_client.model.scatter_label import ScatterLabel
from openapi_client.model.scatter_viz import ScatterViz
from openapi_client.model.scatter_viz_data_state import ScatterVizDataState
from openapi_client.model.secret_manager import SecretManager
from openapi_client.model.send_reset_password_mail_params import SendResetPasswordMailParams
from openapi_client.model.send_reset_password_mail_response import SendResetPasswordMailResponse
from openapi_client.model.send_user_message_params import SendUserMessageParams
from openapi_client.model.send_user_message_response import SendUserMessageResponse
from openapi_client.model.set_default_organization_request import SetDefaultOrganizationRequest
from openapi_client.model.set_organization_machine_type_params import SetOrganizationMachineTypeParams
from openapi_client.model.set_user_metadata_inner_params import SetUserMetadataInnerParams
from openapi_client.model.set_user_metadata_params import SetUserMetadataParams
from openapi_client.model.set_user_metadata_response import SetUserMetadataResponse
from openapi_client.model.signup_params import SignupParams
from openapi_client.model.signup_response import SignupResponse
from openapi_client.model.single_user_mode_settings import SingleUserModeSettings
from openapi_client.model.sized_layout import SizedLayout
from openapi_client.model.slim_organization import SlimOrganization
from openapi_client.model.slim_user_data import SlimUserData
from openapi_client.model.slim_user_data_local import SlimUserDataLocal
from openapi_client.model.slim_version import SlimVersion
from openapi_client.model.slim_visualization import SlimVisualization
from openapi_client.model.space_kibana_dashboard import SpaceKibanaDashboard
from openapi_client.model.start_trial_params import StartTrialParams
from openapi_client.model.stop_job_params import StopJobParams
from openapi_client.model.stop_job_response import StopJobResponse
from openapi_client.model.terminate_job_params import TerminateJobParams
from openapi_client.model.terminate_job_response import TerminateJobResponse
from openapi_client.model.test_status import TestStatus
from openapi_client.model.text_data import TextData
from openapi_client.model.text_mask_scatter_label import TextMaskScatterLabel
from openapi_client.model.text_scatter_label import TextScatterLabel
from openapi_client.model.text_viz import TextViz
from openapi_client.model.tour_step_definition import TourStepDefinition
from openapi_client.model.train_from_initial_weights_params import TrainFromInitialWeightsParams
from openapi_client.model.train_from_scratch_params import TrainFromScratchParams
from openapi_client.model.training_params import TrainingParams
from openapi_client.model.trash_dataset_params import TrashDatasetParams
from openapi_client.model.trash_project_params import TrashProjectParams
from openapi_client.model.trash_secret_manager_params import TrashSecretManagerParams
from openapi_client.model.trash_secret_manager_response import TrashSecretManagerResponse
from openapi_client.model.under_representation_insight import UnderRepresentationInsight
from openapi_client.model.update_dashboard_params import UpdateDashboardParams
from openapi_client.model.update_issue_params import UpdateIssueParams
from openapi_client.model.update_model_test_request import UpdateModelTestRequest
from openapi_client.model.update_organization_public_name_request import UpdateOrganizationPublicNameRequest
from openapi_client.model.update_secret_manager_params import UpdateSecretManagerParams
from openapi_client.model.update_secret_manager_response import UpdateSecretManagerResponse
from openapi_client.model.update_user_name_request import UpdateUserNameRequest
from openapi_client.model.update_user_organization_request import UpdateUserOrganizationRequest
from openapi_client.model.update_user_role_request import UpdateUserRoleRequest
from openapi_client.model.update_user_status_request import UpdateUserStatusRequest
from openapi_client.model.update_version_params import UpdateVersionParams
from openapi_client.model.update_version_response import UpdateVersionResponse
from openapi_client.model.user_data import UserData
from openapi_client.model.user_data_local import UserDataLocal
from openapi_client.model.user_data_metadata import UserDataMetadata
from openapi_client.model.user_role import UserRole
from openapi_client.model.version import Version
from openapi_client.model.vertical_charts import VerticalCharts
from openapi_client.model.vis_data import VisData
from openapi_client.model.visualization import Visualization
from openapi_client.model.visualization_data import VisualizationData
from openapi_client.model.visualization_item import VisualizationItem
from openapi_client.model.visualization_response import VisualizationResponse
from openapi_client.model.visualized_item import VisualizedItem
from openapi_client.model.visualizer_instance import VisualizerInstance
from openapi_client.model.visualizer_message_params import VisualizerMessageParams
from openapi_client.model.viz_info_type import VizInfoType
from openapi_client.model.viz_type import VizType
from openapi_client.model.x_meta_axis import XMetaAxis
from openapi_client.model.xy_chart import XYChart
from openapi_client.model.xy_charts_meta import XYChartsMeta
from openapi_client.model.xy_charts_response import XYChartsResponse
from openapi_client.model.y_meta_axis import YMetaAxis



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ImportNewModelParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "modelName",
            "fileName",
            "model_type",
            "versionName",
            "projectId",
        }
        
        class properties:
            projectId = schemas.StrSchema
            fileName = schemas.StrSchema
            modelName = schemas.StrSchema
            versionName = schemas.StrSchema
        
            @staticmethod
            def model_type() -> typing.Type['ImportModelType']:
                return ImportModelType
            datasetId = schemas.StrSchema
            branchName = schemas.StrSchema
            transform_inputs = schemas.BoolSchema
            __annotations__ = {
                "projectId": projectId,
                "fileName": fileName,
                "modelName": modelName,
                "versionName": versionName,
                "model_type": model_type,
                "datasetId": datasetId,
                "branchName": branchName,
                "transform_inputs": transform_inputs,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    modelName: MetaOapg.properties.modelName
    fileName: MetaOapg.properties.fileName
    model_type: 'ImportModelType'
    versionName: MetaOapg.properties.versionName
    projectId: MetaOapg.properties.projectId
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fileName"]) -> MetaOapg.properties.fileName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["model_type"]) -> 'ImportModelType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["versionName"]) -> MetaOapg.properties.versionName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["datasetId"]) -> MetaOapg.properties.datasetId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["branchName"]) -> MetaOapg.properties.branchName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transform_inputs"]) -> MetaOapg.properties.transform_inputs: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["modelName"], typing_extensions.Literal["fileName"], typing_extensions.Literal["model_type"], typing_extensions.Literal["versionName"], typing_extensions.Literal["projectId"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["branchName"], typing_extensions.Literal["transform_inputs"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fileName"]) -> MetaOapg.properties.fileName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["model_type"]) -> 'ImportModelType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["versionName"]) -> MetaOapg.properties.versionName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["datasetId"]) -> typing.Union[MetaOapg.properties.datasetId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["branchName"]) -> typing.Union[MetaOapg.properties.branchName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transform_inputs"]) -> typing.Union[MetaOapg.properties.transform_inputs, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["modelName"], typing_extensions.Literal["fileName"], typing_extensions.Literal["model_type"], typing_extensions.Literal["versionName"], typing_extensions.Literal["projectId"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["branchName"], typing_extensions.Literal["transform_inputs"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        modelName: typing.Union[MetaOapg.properties.modelName, str, ],
        fileName: typing.Union[MetaOapg.properties.fileName, str, ],
        model_type: 'ImportModelType',
        versionName: typing.Union[MetaOapg.properties.versionName, str, ],
        projectId: typing.Union[MetaOapg.properties.projectId, str, ],
        datasetId: typing.Union[MetaOapg.properties.datasetId, str, schemas.Unset] = schemas.unset,
        branchName: typing.Union[MetaOapg.properties.branchName, str, schemas.Unset] = schemas.unset,
        transform_inputs: typing.Union[MetaOapg.properties.transform_inputs, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ImportNewModelParams':
        return super().__new__(
            cls,
            *args,
            modelName=modelName,
            fileName=fileName,
            model_type=model_type,
            versionName=versionName,
            projectId=projectId,
            datasetId=datasetId,
            branchName=branchName,
            transform_inputs=transform_inputs,
            _configuration=_configuration,
        )

from openapi_client.model.import_model_type import ImportModelType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class AddExportModelJobParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "fromEpoch",
            "pruneModel",
            "exportModelType",
            "targetModelId",
            "title",
        }
        
        class properties:
            targetModelId = schemas.StrSchema
        
            @staticmethod
            def exportModelType() -> typing.Type['ExportModelTypeEnum']:
                return ExportModelTypeEnum
            title = schemas.StrSchema
            pruneModel = schemas.BoolSchema
            fromEpoch = schemas.Float64Schema
            __annotations__ = {
                "targetModelId": targetModelId,
                "exportModelType": exportModelType,
                "title": title,
                "pruneModel": pruneModel,
                "fromEpoch": fromEpoch,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    fromEpoch: MetaOapg.properties.fromEpoch
    pruneModel: MetaOapg.properties.pruneModel
    exportModelType: 'ExportModelTypeEnum'
    targetModelId: MetaOapg.properties.targetModelId
    title: MetaOapg.properties.title
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromEpoch"]) -> MetaOapg.properties.fromEpoch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pruneModel"]) -> MetaOapg.properties.pruneModel: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exportModelType"]) -> 'ExportModelTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["targetModelId"]) -> MetaOapg.properties.targetModelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["fromEpoch"], typing_extensions.Literal["pruneModel"], typing_extensions.Literal["exportModelType"], typing_extensions.Literal["targetModelId"], typing_extensions.Literal["title"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromEpoch"]) -> MetaOapg.properties.fromEpoch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pruneModel"]) -> MetaOapg.properties.pruneModel: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exportModelType"]) -> 'ExportModelTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["targetModelId"]) -> MetaOapg.properties.targetModelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["fromEpoch"], typing_extensions.Literal["pruneModel"], typing_extensions.Literal["exportModelType"], typing_extensions.Literal["targetModelId"], typing_extensions.Literal["title"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        fromEpoch: typing.Union[MetaOapg.properties.fromEpoch, decimal.Decimal, int, float, ],
        pruneModel: typing.Union[MetaOapg.properties.pruneModel, bool, ],
        exportModelType: 'ExportModelTypeEnum',
        targetModelId: typing.Union[MetaOapg.properties.targetModelId, str, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AddExportModelJobParams':
        return super().__new__(
            cls,
            *args,
            fromEpoch=fromEpoch,
            pruneModel=pruneModel,
            exportModelType=exportModelType,
            targetModelId=targetModelId,
            title=title,
            _configuration=_configuration,
        )

from openapi_client.model.export_model_type_enum import ExportModelTypeEnum



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class MaskImageScatterLabel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "mask_blob",
            "blob",
            "data",
            "src",
            "mask_src",
            "type",
            "labels",
        }
        
        class properties:
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.ListSchema
                    ):
                    
                    
                        class MetaOapg:
                            items = schemas.Float64Schema
                    
                        def __new__(
                            cls,
                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]]],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                arg,
                                _configuration=_configuration,
                            )
                    
                        def __getitem__(self, i: int) -> MetaOapg.items:
                            return super().__getitem__(i)
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, list, tuple, ]], typing.List[typing.Union[MetaOapg.items, list, tuple, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            src = schemas.StrSchema
            blob = schemas.StrSchema
            type = schemas.StrSchema
            mask_src = schemas.StrSchema
            mask_blob = schemas.StrSchema
            
            
            class labels(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'labels':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            input_name = schemas.StrSchema
            __annotations__ = {
                "data": data,
                "src": src,
                "blob": blob,
                "type": type,
                "mask_src": mask_src,
                "mask_blob": mask_blob,
                "labels": labels,
                "input_name": input_name,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    mask_blob: MetaOapg.properties.mask_blob
    blob: MetaOapg.properties.blob
    data: MetaOapg.properties.data
    src: MetaOapg.properties.src
    mask_src: MetaOapg.properties.mask_src
    type: MetaOapg.properties.type
    labels: MetaOapg.properties.labels
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mask_blob"]) -> MetaOapg.properties.mask_blob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mask_src"]) -> MetaOapg.properties.mask_src: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["labels"]) -> MetaOapg.properties.labels: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input_name"]) -> MetaOapg.properties.input_name: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["mask_blob"], typing_extensions.Literal["blob"], typing_extensions.Literal["data"], typing_extensions.Literal["src"], typing_extensions.Literal["mask_src"], typing_extensions.Literal["type"], typing_extensions.Literal["labels"], typing_extensions.Literal["input_name"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mask_blob"]) -> MetaOapg.properties.mask_blob: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mask_src"]) -> MetaOapg.properties.mask_src: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["labels"]) -> MetaOapg.properties.labels: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input_name"]) -> typing.Union[MetaOapg.properties.input_name, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["mask_blob"], typing_extensions.Literal["blob"], typing_extensions.Literal["data"], typing_extensions.Literal["src"], typing_extensions.Literal["mask_src"], typing_extensions.Literal["type"], typing_extensions.Literal["labels"], typing_extensions.Literal["input_name"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        mask_blob: typing.Union[MetaOapg.properties.mask_blob, str, ],
        blob: typing.Union[MetaOapg.properties.blob, str, ],
        data: typing.Union[MetaOapg.properties.data, list, tuple, ],
        src: typing.Union[MetaOapg.properties.src, str, ],
        mask_src: typing.Union[MetaOapg.properties.mask_src, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        labels: typing.Union[MetaOapg.properties.labels, list, tuple, ],
        input_name: typing.Union[MetaOapg.properties.input_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MaskImageScatterLabel':
        return super().__new__(
            cls,
            *args,
            mask_blob=mask_blob,
            blob=blob,
            data=data,
            src=src,
            mask_src=mask_src,
            type=type,
            labels=labels,
            input_name=input_name,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from openapi_client.paths.auth_activate.post import Activate
from openapi_client.paths.dashboards_add_dashboard.post import AddDashboard
from openapi_client.paths.datasets_add_dataset.post import AddDataset
from openapi_client.paths.jobs_add_export_model_job.post import AddExportModelJob
from openapi_client.paths.issues_add_issue.post import AddIssue
from openapi_client.paths.projects_add_project.post import AddProject
from openapi_client.paths.secret_manager_add_secret_manager.post import AddSecretManager
from openapi_client.paths.versions_add_version.post import AddVersion
from openapi_client.paths.jobs_continue_train.post import ContinueTrain
from openapi_client.paths.model_tests_create_model_test.post import CreateModelTest
from openapi_client.paths.organizations_create_organization.post import CreateOrganization
from openapi_client.paths.dashboards_delete_dashboard.post import DeleteDashboard
from openapi_client.paths.issues_delete_issue.post import DeleteIssue
from openapi_client.paths.models_delete_model.post import DeleteModel
from openapi_client.paths.model_tests_delete_model_test.post import DeleteModelTest
from openapi_client.paths.organizations_delete_organization.post import DeleteOrganization
from openapi_client.paths.projects_delete_project.post import DeleteProject
from openapi_client.paths.users_delete_user_by_id.post import DeleteUserById
from openapi_client.paths.versions_delete_version.post import DeleteVersion
from openapi_client.paths.visualizations_delete_visualizations.post import DeleteVisualizations
from openapi_client.paths.jobs_evaluate.post import Evaluate
from openapi_client.paths.auth_extend_trial.post import ExtendTrial
from openapi_client.paths.model_tests_get_all_project_model_tests.post import GetAllProjectModelTests
from openapi_client.paths.users_get_all_slim_user_data.post import GetAllSlimUserData
from openapi_client.paths.modelmetrics_get_balanced_accuracy.post import GetBalancedAccuracy
from openapi_client.paths.modelmetrics_get_confusion_metric_names.post import GetConfusionMetricNames
from openapi_client.paths.projects_get_current_project_version.post import GetCurrentProjectVersion
from openapi_client.paths.dashboards_get_dashboard.post import GetDashboard
from openapi_client.paths.dashboards_get_dashlet_fields.post import GetDashletFields
from openapi_client.paths.datasets_get_dataset_version.post import GetDatasetVersion
from openapi_client.paths.datasets_get_dataset_versions.post import GetDatasetVersions
from openapi_client.paths.datasets_get_datasets.post import GetDatasets
from openapi_client.paths.demos_get_demos.post import GetDemos
from openapi_client.paths.exportedmodels_get_exported_model_jobs.post import GetExportedModelJobs
from openapi_client.paths.modelmetrics_get_f1_score.post import GetF1Score
from openapi_client.paths.modelmetrics_get_heatmap_chart.post import GetHeatmapChart
from openapi_client.paths.jobs_get_jobs.post import GetJobs
from openapi_client.paths.dashboards_get_kibana_dashboards.post import GetKibanaDashboards
from openapi_client.paths.dashboards_get_kibana_dashlet_fields.post import GetKibanaDashletFields
from openapi_client.paths.datasets_get_latest_dataset_version.post import GetLatestDatasetVersion
from openapi_client.paths.jobs_get_machine_types.post import GetMachineTypes
from openapi_client.paths.metadata_get_max_active_users.post import GetMaxActiveUsers
from openapi_client.paths.modelmetrics_get_model_epoch_loss.post import GetModelEpochLoss
from openapi_client.paths.insights_get_model_insights.post import GetModelInsights
from openapi_client.paths.model_tests_get_model_test_result.post import GetModelTestResult
from openapi_client.paths.visualizations_get_model_visualizations.post import GetModelVisualizations
from openapi_client.paths.models_get_models_by_hash.post import GetModelsByHash
from openapi_client.paths.models_get_models_by_version_id.post import GetModelsByVersionId
from openapi_client.paths.notifications_get_notifications.post import GetNotifications
from openapi_client.paths.jobs_get_organization_jobs.post import GetOrganizationJobs
from openapi_client.paths.users_get_organization_slim_user_data.post import GetOrganizationSlimUserData
from openapi_client.paths.organizations_get_organizations.post import GetOrganizations
from openapi_client.paths.modelmetrics_get_pr_curve.post import GetPrCurve
from openapi_client.paths.dashboards_get_project_dashboards.post import GetProjectDashboards
from openapi_client.paths.issues_get_project_issues.post import GetProjectIssues
from openapi_client.paths.versions_get_project_slim_versions.post import GetProjectSlimVersions
from openapi_client.paths.projects_get_projects.post import GetProjects
from openapi_client.paths.models_get_recent_organization_models.post import GetRecentOrganizationModels
from openapi_client.paths.modelmetrics_get_roc.post import GetRoc
from openapi_client.paths.secret_manager_get_secret_manager_list.post import GetSecretManagerList
from openapi_client.paths.issues_get_single_issue.post import GetSingleIssue
from openapi_client.paths.model_tests_get_single_model_test.post import GetSingleModelTest
from openapi_client.paths.metadata_get_statistics.post import GetStatistics
from openapi_client.paths.exportedmodels_get_stored_exported_model_resource_url.post import GetStoredExportedModelResourceUrl
from openapi_client.paths.visualizations_get_stored_resource_url.post import GetStoredResourceUrl
from openapi_client.paths.modelmetrics_get_table_chart.post import GetTableChart
from openapi_client.paths.jobs_get_training_jobs.post import GetTrainingJobs
from openapi_client.paths.versions_get_upload_signed_url.post import GetUploadSignedUrl
from openapi_client.paths.visualizations_get_visualization.post import GetVisualization
from openapi_client.paths.modelmetrics_get_xy_chart.post import GetXyChart
from openapi_client.paths.monitor_health_check.get import HealthCheck
from openapi_client.paths.demos_import_demo_project.post import ImportDemoProject
from openapi_client.paths.versions_import_model.post import ImportModel
from openapi_client.paths.jobs_is_training_job_running.post import IsTrainingJobRunning
from openapi_client.paths.auth_keygen.post import KeyGen
from openapi_client.paths.auth_keylogin.post import KeyLogin
from openapi_client.paths.projects_load_model.post import LoadModel
from openapi_client.paths.versions_load_version.post import LoadVersion
from openapi_client.paths.auth_login.post import Login
from openapi_client.paths.auth_logout.post import Logout
from openapi_client.paths.datasets_modify_dataset_version_note.post import ModifyDatasetVersionNote
from openapi_client.paths.datasets_parse_dataset.post import ParseDataset
from openapi_client.paths.jobs_population_exploration.post import PopulationExploration
from openapi_client.paths.auth_request_trial.post import RequestTrial
from openapi_client.paths.auth_resend_activation_mail.post import ResendActivationMail
from openapi_client.paths.auth_reset_password.post import ResetPassword
from openapi_client.paths.jobs_sample_analysis.post import SampleAnalysis
from openapi_client.paths.jobs_sample_selection.post import SampleSelection
from openapi_client.paths.visualizations_save_analyzer_layout.post import SaveAnalyzerLayout
from openapi_client.paths.datasets_save_dataset_version.post import SaveDatasetVersion
from openapi_client.paths.auth_send_reset_password_mail.post import SendResetPasswordMail
from openapi_client.paths.demos_send_user_message.post import SendUserMessage
from openapi_client.paths.organizations_set_default_organization.post import SetDefaultOrganization
from openapi_client.paths.jobs_set_machine_type.post import SetOrganizationMachineType
from openapi_client.paths.auth_set_user_metadata.post import SetUserMetadata
from openapi_client.paths.notifications_set_user_notifications_as_read.post import SetUserNotificationsAsRead
from openapi_client.paths.auth_signup.post import Signup
from openapi_client.paths.auth_start_trial.post import StartTrial
from openapi_client.paths.jobs_stop_job.post import StopJob
from openapi_client.paths.jobs_terminate_job.post import TerminateJob
from openapi_client.paths.jobs_train_from_initial_weights.post import TrainFromInitialWeights
from openapi_client.paths.jobs_train_from_scratch.post import TrainFromScratch
from openapi_client.paths.datasets_trash_dataset.post import TrashDataset
from openapi_client.paths.projects_trash_project.post import TrashProject
from openapi_client.paths.secret_manager_trash_secret_manager.post import TrashSecretManager
from openapi_client.paths.dashboards_update_dashboard.post import UpdateDashboard
from openapi_client.paths.issues_update_issue.post import UpdateIssue
from openapi_client.paths.model_tests_update_model_test.post import UpdateModelTest
from openapi_client.paths.organizations_update_organization_public_name.post import UpdateOrganizationPublicName
from openapi_client.paths.secret_manager_update_secret_manager.post import UpdateSecretManager
from openapi_client.paths.users_update_user_name.post import UpdateUserName
from openapi_client.paths.users_update_user_organization.post import UpdateUserOrganization
from openapi_client.paths.users_update_user_role.post import UpdateUserRole
from openapi_client.paths.users_update_user_status.post import UpdateUserStatus
from openapi_client.paths.versions_update_version.post import UpdateVersion
from openapi_client.paths.jobs_warmup.post import Warmup
from openapi_client.paths.auth_who_am_i.post import WhoAmI


class DefaultApi(
    Activate,
    AddDashboard,
    AddDataset,
    AddExportModelJob,
    AddIssue,
    AddProject,
    AddSecretManager,
    AddVersion,
    ContinueTrain,
    CreateModelTest,
    CreateOrganization,
    DeleteDashboard,
    DeleteIssue,
    DeleteModel,
    DeleteModelTest,
    DeleteOrganization,
    DeleteProject,
    DeleteUserById,
    DeleteVersion,
    DeleteVisualizations,
    Evaluate,
    ExtendTrial,
    GetAllProjectModelTests,
    GetAllSlimUserData,
    GetBalancedAccuracy,
    GetConfusionMetricNames,
    GetCurrentProjectVersion,
    GetDashboard,
    GetDashletFields,
    GetDatasetVersion,
    GetDatasetVersions,
    GetDatasets,
    GetDemos,
    GetExportedModelJobs,
    GetF1Score,
    GetHeatmapChart,
    GetJobs,
    GetKibanaDashboards,
    GetKibanaDashletFields,
    GetLatestDatasetVersion,
    GetMachineTypes,
    GetMaxActiveUsers,
    GetModelEpochLoss,
    GetModelInsights,
    GetModelTestResult,
    GetModelVisualizations,
    GetModelsByHash,
    GetModelsByVersionId,
    GetNotifications,
    GetOrganizationJobs,
    GetOrganizationSlimUserData,
    GetOrganizations,
    GetPrCurve,
    GetProjectDashboards,
    GetProjectIssues,
    GetProjectSlimVersions,
    GetProjects,
    GetRecentOrganizationModels,
    GetRoc,
    GetSecretManagerList,
    GetSingleIssue,
    GetSingleModelTest,
    GetStatistics,
    GetStoredExportedModelResourceUrl,
    GetStoredResourceUrl,
    GetTableChart,
    GetTrainingJobs,
    GetUploadSignedUrl,
    GetVisualization,
    GetXyChart,
    HealthCheck,
    ImportDemoProject,
    ImportModel,
    IsTrainingJobRunning,
    KeyGen,
    KeyLogin,
    LoadModel,
    LoadVersion,
    Login,
    Logout,
    ModifyDatasetVersionNote,
    ParseDataset,
    PopulationExploration,
    RequestTrial,
    ResendActivationMail,
    ResetPassword,
    SampleAnalysis,
    SampleSelection,
    SaveAnalyzerLayout,
    SaveDatasetVersion,
    SendResetPasswordMail,
    SendUserMessage,
    SetDefaultOrganization,
    SetOrganizationMachineType,
    SetUserMetadata,
    SetUserNotificationsAsRead,
    Signup,
    StartTrial,
    StopJob,
    TerminateJob,
    TrainFromInitialWeights,
    TrainFromScratch,
    TrashDataset,
    TrashProject,
    TrashSecretManager,
    UpdateDashboard,
    UpdateIssue,
    UpdateModelTest,
    UpdateOrganizationPublicName,
    UpdateSecretManager,
    UpdateUserName,
    UpdateUserOrganization,
    UpdateUserRole,
    UpdateUserStatus,
    UpdateVersion,
    Warmup,
    WhoAmI,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class AddIssueParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "title",
            "projectId",
            "status",
        }
        
        class properties:
            projectId = schemas.StrSchema
            title = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['IssueStatus']:
                return IssueStatus
            branch = schemas.StrSchema
            
            
            class tags(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'tags':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            assignment = schemas.StrSchema
            
            
            class activities(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['IssueActivity']:
                        return IssueActivity
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['IssueActivity'], typing.List['IssueActivity']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'activities':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'IssueActivity':
                    return super().__getitem__(i)
            __annotations__ = {
                "projectId": projectId,
                "title": title,
                "status": status,
                "branch": branch,
                "tags": tags,
                "assignment": assignment,
                "activities": activities,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    title: MetaOapg.properties.title
    projectId: MetaOapg.properties.projectId
    status: 'IssueStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'IssueStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["branch"]) -> MetaOapg.properties.branch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tags"]) -> MetaOapg.properties.tags: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["assignment"]) -> MetaOapg.properties.assignment: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activities"]) -> MetaOapg.properties.activities: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["status"], typing_extensions.Literal["branch"], typing_extensions.Literal["tags"], typing_extensions.Literal["assignment"], typing_extensions.Literal["activities"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'IssueStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["branch"]) -> typing.Union[MetaOapg.properties.branch, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tags"]) -> typing.Union[MetaOapg.properties.tags, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["assignment"]) -> typing.Union[MetaOapg.properties.assignment, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activities"]) -> typing.Union[MetaOapg.properties.activities, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["status"], typing_extensions.Literal["branch"], typing_extensions.Literal["tags"], typing_extensions.Literal["assignment"], typing_extensions.Literal["activities"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        projectId: typing.Union[MetaOapg.properties.projectId, str, ],
        status: 'IssueStatus',
        branch: typing.Union[MetaOapg.properties.branch, str, schemas.Unset] = schemas.unset,
        tags: typing.Union[MetaOapg.properties.tags, list, tuple, schemas.Unset] = schemas.unset,
        assignment: typing.Union[MetaOapg.properties.assignment, str, schemas.Unset] = schemas.unset,
        activities: typing.Union[MetaOapg.properties.activities, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AddIssueParams':
        return super().__new__(
            cls,
            *args,
            title=title,
            projectId=projectId,
            status=status,
            branch=branch,
            tags=tags,
            assignment=assignment,
            activities=activities,
            _configuration=_configuration,
        )

from openapi_client.model.issue_activity import IssueActivity
from openapi_client.model.issue_status import IssueStatus



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class LoadVersionResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "project",
            "version",
        }
        
        class properties:
        
            @staticmethod
            def project() -> typing.Type['Project']:
                return Project
        
            @staticmethod
            def version() -> typing.Type['Version']:
                return Version
            __annotations__ = {
                "project": project,
                "version": version,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    project: 'Project'
    version: 'Version'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["project"]) -> 'Project': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["version"]) -> 'Version': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["project"], typing_extensions.Literal["version"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["project"]) -> 'Project': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["version"]) -> 'Version': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["project"], typing_extensions.Literal["version"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        project: 'Project',
        version: 'Version',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'LoadVersionResponse':
        return super().__new__(
            cls,
            *args,
            project=project,
            version=version,
            _configuration=_configuration,
        )

from openapi_client.model.project import Project
from openapi_client.model.version import Version



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class MultiChartsParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "xField",
            "yField",
            "dataDistributionType",
            "xAxisSizeInterval",
            "modelExtIds",
            "aggregationMethod",
        }
        
        class properties:
            xField = schemas.StrSchema
            yField = schemas.StrSchema
        
            @staticmethod
            def aggregationMethod() -> typing.Type['AggregationMethod']:
                return AggregationMethod
            
            
            class modelExtIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'modelExtIds':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def dataDistributionType() -> typing.Type['DataDistributionType']:
                return DataDistributionType
            xAxisSizeInterval = schemas.Float64Schema
            verticalSplit = schemas.StrSchema
            horizontalSplit = schemas.StrSchema
            innerSplit = schemas.StrSchema
            
            
            class filters(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ESFilter']:
                        return ESFilter
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ESFilter'], typing.List['ESFilter']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'filters':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ESFilter':
                    return super().__getitem__(i)
            orderByParam = schemas.StrSchema
        
            @staticmethod
            def orderParams() -> typing.Type['OrderType']:
                return OrderType
            lastEpochOnly = schemas.BoolSchema
            __annotations__ = {
                "xField": xField,
                "yField": yField,
                "aggregationMethod": aggregationMethod,
                "modelExtIds": modelExtIds,
                "dataDistributionType": dataDistributionType,
                "xAxisSizeInterval": xAxisSizeInterval,
                "verticalSplit": verticalSplit,
                "horizontalSplit": horizontalSplit,
                "innerSplit": innerSplit,
                "filters": filters,
                "orderByParam": orderByParam,
                "orderParams": orderParams,
                "lastEpochOnly": lastEpochOnly,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    xField: MetaOapg.properties.xField
    yField: MetaOapg.properties.yField
    dataDistributionType: 'DataDistributionType'
    xAxisSizeInterval: MetaOapg.properties.xAxisSizeInterval
    modelExtIds: MetaOapg.properties.modelExtIds
    aggregationMethod: 'AggregationMethod'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["xField"]) -> MetaOapg.properties.xField: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["yField"]) -> MetaOapg.properties.yField: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dataDistributionType"]) -> 'DataDistributionType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["xAxisSizeInterval"]) -> MetaOapg.properties.xAxisSizeInterval: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["aggregationMethod"]) -> 'AggregationMethod': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verticalSplit"]) -> MetaOapg.properties.verticalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["horizontalSplit"]) -> MetaOapg.properties.horizontalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["innerSplit"]) -> MetaOapg.properties.innerSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["filters"]) -> MetaOapg.properties.filters: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderByParam"]) -> MetaOapg.properties.orderByParam: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderParams"]) -> 'OrderType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["lastEpochOnly"]) -> MetaOapg.properties.lastEpochOnly: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["xField"], typing_extensions.Literal["yField"], typing_extensions.Literal["dataDistributionType"], typing_extensions.Literal["xAxisSizeInterval"], typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["aggregationMethod"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["innerSplit"], typing_extensions.Literal["filters"], typing_extensions.Literal["orderByParam"], typing_extensions.Literal["orderParams"], typing_extensions.Literal["lastEpochOnly"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["xField"]) -> MetaOapg.properties.xField: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["yField"]) -> MetaOapg.properties.yField: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dataDistributionType"]) -> 'DataDistributionType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["xAxisSizeInterval"]) -> MetaOapg.properties.xAxisSizeInterval: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["aggregationMethod"]) -> 'AggregationMethod': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verticalSplit"]) -> typing.Union[MetaOapg.properties.verticalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["horizontalSplit"]) -> typing.Union[MetaOapg.properties.horizontalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["innerSplit"]) -> typing.Union[MetaOapg.properties.innerSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["filters"]) -> typing.Union[MetaOapg.properties.filters, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderByParam"]) -> typing.Union[MetaOapg.properties.orderByParam, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderParams"]) -> typing.Union['OrderType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["lastEpochOnly"]) -> typing.Union[MetaOapg.properties.lastEpochOnly, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["xField"], typing_extensions.Literal["yField"], typing_extensions.Literal["dataDistributionType"], typing_extensions.Literal["xAxisSizeInterval"], typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["aggregationMethod"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["innerSplit"], typing_extensions.Literal["filters"], typing_extensions.Literal["orderByParam"], typing_extensions.Literal["orderParams"], typing_extensions.Literal["lastEpochOnly"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        xField: typing.Union[MetaOapg.properties.xField, str, ],
        yField: typing.Union[MetaOapg.properties.yField, str, ],
        dataDistributionType: 'DataDistributionType',
        xAxisSizeInterval: typing.Union[MetaOapg.properties.xAxisSizeInterval, decimal.Decimal, int, float, ],
        modelExtIds: typing.Union[MetaOapg.properties.modelExtIds, list, tuple, ],
        aggregationMethod: 'AggregationMethod',
        verticalSplit: typing.Union[MetaOapg.properties.verticalSplit, str, schemas.Unset] = schemas.unset,
        horizontalSplit: typing.Union[MetaOapg.properties.horizontalSplit, str, schemas.Unset] = schemas.unset,
        innerSplit: typing.Union[MetaOapg.properties.innerSplit, str, schemas.Unset] = schemas.unset,
        filters: typing.Union[MetaOapg.properties.filters, list, tuple, schemas.Unset] = schemas.unset,
        orderByParam: typing.Union[MetaOapg.properties.orderByParam, str, schemas.Unset] = schemas.unset,
        orderParams: typing.Union['OrderType', schemas.Unset] = schemas.unset,
        lastEpochOnly: typing.Union[MetaOapg.properties.lastEpochOnly, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MultiChartsParams':
        return super().__new__(
            cls,
            *args,
            xField=xField,
            yField=yField,
            dataDistributionType=dataDistributionType,
            xAxisSizeInterval=xAxisSizeInterval,
            modelExtIds=modelExtIds,
            aggregationMethod=aggregationMethod,
            verticalSplit=verticalSplit,
            horizontalSplit=horizontalSplit,
            innerSplit=innerSplit,
            filters=filters,
            orderByParam=orderByParam,
            orderParams=orderParams,
            lastEpochOnly=lastEpochOnly,
            _configuration=_configuration,
        )

from openapi_client.model.aggregation_method import AggregationMethod
from openapi_client.model.data_distribution_type import DataDistributionType
from openapi_client.model.es_filter import ESFilter
from openapi_client.model.order_type import OrderType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class FilterOperatorType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "between": "BETWEEN",
            "not-between": "NOTBETWEEN",
            "equal": "EQUAL",
            "not-equal": "NOTEQUAL",
            "in": "IN",
            "greater-than": "GREATERTHAN",
            "less-than": "LESSTHAN",
        }
    
    @schemas.classproperty
    def BETWEEN(cls):
        return cls("between")
    
    @schemas.classproperty
    def NOTBETWEEN(cls):
        return cls("not-between")
    
    @schemas.classproperty
    def EQUAL(cls):
        return cls("equal")
    
    @schemas.classproperty
    def NOTEQUAL(cls):
        return cls("not-equal")
    
    @schemas.classproperty
    def IN(cls):
        return cls("in")
    
    @schemas.classproperty
    def GREATERTHAN(cls):
        return cls("greater-than")
    
    @schemas.classproperty
    def LESSTHAN(cls):
        return cls("less-than")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class VisualizedItem(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "connection_name",
            "data",
            "encoder_names",
            "visualizer_name",
        }
        
        class properties:
            visualizer_name = schemas.StrSchema
        
            @staticmethod
            def data() -> typing.Type['VisData']:
                return VisData
            
            
            class encoder_names(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'encoder_names':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            connection_name = schemas.StrSchema
            __annotations__ = {
                "visualizer_name": visualizer_name,
                "data": data,
                "encoder_names": encoder_names,
                "connection_name": connection_name,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    connection_name: MetaOapg.properties.connection_name
    data: 'VisData'
    encoder_names: MetaOapg.properties.encoder_names
    visualizer_name: MetaOapg.properties.visualizer_name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["connection_name"]) -> MetaOapg.properties.connection_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> 'VisData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["encoder_names"]) -> MetaOapg.properties.encoder_names: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visualizer_name"]) -> MetaOapg.properties.visualizer_name: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["connection_name"], typing_extensions.Literal["data"], typing_extensions.Literal["encoder_names"], typing_extensions.Literal["visualizer_name"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["connection_name"]) -> MetaOapg.properties.connection_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> 'VisData': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["encoder_names"]) -> MetaOapg.properties.encoder_names: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visualizer_name"]) -> MetaOapg.properties.visualizer_name: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["connection_name"], typing_extensions.Literal["data"], typing_extensions.Literal["encoder_names"], typing_extensions.Literal["visualizer_name"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        connection_name: typing.Union[MetaOapg.properties.connection_name, str, ],
        data: 'VisData',
        encoder_names: typing.Union[MetaOapg.properties.encoder_names, list, tuple, ],
        visualizer_name: typing.Union[MetaOapg.properties.visualizer_name, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'VisualizedItem':
        return super().__new__(
            cls,
            *args,
            connection_name=connection_name,
            data=data,
            encoder_names=encoder_names,
            visualizer_name=visualizer_name,
            _configuration=_configuration,
        )

from openapi_client.model.vis_data import VisData



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class OverfittingInsight(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "filter",
            "avg_loss_training",
            "n_samples_training",
            "avg_loss_validation",
            "n_samples_validation",
            "type",
        }
        
        class properties:
        
            @staticmethod
            def type() -> typing.Type['ScatterInsightType']:
                return ScatterInsightType
        
            @staticmethod
            def filter() -> typing.Type['ScatterFilter']:
                return ScatterFilter
            n_samples_validation = schemas.Float64Schema
            n_samples_training = schemas.Float64Schema
            avg_loss_validation = schemas.Float64Schema
            avg_loss_training = schemas.Float64Schema
            __annotations__ = {
                "type": type,
                "filter": filter,
                "n_samples_validation": n_samples_validation,
                "n_samples_training": n_samples_training,
                "avg_loss_validation": avg_loss_validation,
                "avg_loss_training": avg_loss_training,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    filter: 'ScatterFilter'
    avg_loss_training: MetaOapg.properties.avg_loss_training
    n_samples_training: MetaOapg.properties.n_samples_training
    avg_loss_validation: MetaOapg.properties.avg_loss_validation
    n_samples_validation: MetaOapg.properties.n_samples_validation
    type: 'ScatterInsightType'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["filter"]) -> 'ScatterFilter': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["avg_loss_training"]) -> MetaOapg.properties.avg_loss_training: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["n_samples_training"]) -> MetaOapg.properties.n_samples_training: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["avg_loss_validation"]) -> MetaOapg.properties.avg_loss_validation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["n_samples_validation"]) -> MetaOapg.properties.n_samples_validation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'ScatterInsightType': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["filter"], typing_extensions.Literal["avg_loss_training"], typing_extensions.Literal["n_samples_training"], typing_extensions.Literal["avg_loss_validation"], typing_extensions.Literal["n_samples_validation"], typing_extensions.Literal["type"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["filter"]) -> 'ScatterFilter': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["avg_loss_training"]) -> MetaOapg.properties.avg_loss_training: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["n_samples_training"]) -> MetaOapg.properties.n_samples_training: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["avg_loss_validation"]) -> MetaOapg.properties.avg_loss_validation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["n_samples_validation"]) -> MetaOapg.properties.n_samples_validation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'ScatterInsightType': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["filter"], typing_extensions.Literal["avg_loss_training"], typing_extensions.Literal["n_samples_training"], typing_extensions.Literal["avg_loss_validation"], typing_extensions.Literal["n_samples_validation"], typing_extensions.Literal["type"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        filter: 'ScatterFilter',
        avg_loss_training: typing.Union[MetaOapg.properties.avg_loss_training, decimal.Decimal, int, float, ],
        n_samples_training: typing.Union[MetaOapg.properties.n_samples_training, decimal.Decimal, int, float, ],
        avg_loss_validation: typing.Union[MetaOapg.properties.avg_loss_validation, decimal.Decimal, int, float, ],
        n_samples_validation: typing.Union[MetaOapg.properties.n_samples_validation, decimal.Decimal, int, float, ],
        type: 'ScatterInsightType',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'OverfittingInsight':
        return super().__new__(
            cls,
            *args,
            filter=filter,
            avg_loss_training=avg_loss_training,
            n_samples_training=n_samples_training,
            avg_loss_validation=avg_loss_validation,
            n_samples_validation=n_samples_validation,
            type=type,
            _configuration=_configuration,
        )

from openapi_client.model.scatter_filter import ScatterFilter
from openapi_client.model.scatter_insight_type import ScatterInsightType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DataTypeEnum(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "image": "IMAGE",
            "word": "WORD",
            "text": "TEXT",
            "mask_text": "MASK_TEXT",
            "graph": "GRAPH",
            "hbar": "HBAR",
            "bbox_image": "BBOX_IMAGE",
            "mask_image": "MASK_IMAGE",
        }
    
    @schemas.classproperty
    def IMAGE(cls):
        return cls("image")
    
    @schemas.classproperty
    def WORD(cls):
        return cls("word")
    
    @schemas.classproperty
    def TEXT(cls):
        return cls("text")
    
    @schemas.classproperty
    def MASK_TEXT(cls):
        return cls("mask_text")
    
    @schemas.classproperty
    def GRAPH(cls):
        return cls("graph")
    
    @schemas.classproperty
    def HBAR(cls):
        return cls("hbar")
    
    @schemas.classproperty
    def BBOX_IMAGE(cls):
        return cls("bbox_image")
    
    @schemas.classproperty
    def MASK_IMAGE(cls):
        return cls("mask_image")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class SampleAnalysisViz(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "sub_title",
            "visualized_items",
            "metadata_map",
            "guid",
            "grads_analysis",
            "title",
            "type",
            "feature_importance",
        }
        
        class properties:
            type = schemas.StrSchema
            title = schemas.StrSchema
            sub_title = schemas.StrSchema
            guid = schemas.StrSchema
            
            
            class visualized_items(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['VisualizedItem']:
                        return VisualizedItem
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['VisualizedItem'], typing.List['VisualizedItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'visualized_items':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'VisualizedItem':
                    return super().__getitem__(i)
        
            @staticmethod
            def grads_analysis() -> typing.Type['GradsAnalysis']:
                return GradsAnalysis
        
            @staticmethod
            def feature_importance() -> typing.Type['FeatureImportance']:
                return FeatureImportance
            metadata_map = schemas.DictSchema
            __annotations__ = {
                "type": type,
                "title": title,
                "sub_title": sub_title,
                "guid": guid,
                "visualized_items": visualized_items,
                "grads_analysis": grads_analysis,
                "feature_importance": feature_importance,
                "metadata_map": metadata_map,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    sub_title: MetaOapg.properties.sub_title
    visualized_items: MetaOapg.properties.visualized_items
    metadata_map: MetaOapg.properties.metadata_map
    guid: MetaOapg.properties.guid
    grads_analysis: 'GradsAnalysis'
    title: MetaOapg.properties.title
    type: MetaOapg.properties.type
    feature_importance: 'FeatureImportance'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sub_title"]) -> MetaOapg.properties.sub_title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visualized_items"]) -> MetaOapg.properties.visualized_items: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata_map"]) -> MetaOapg.properties.metadata_map: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["guid"]) -> MetaOapg.properties.guid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["grads_analysis"]) -> 'GradsAnalysis': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["feature_importance"]) -> 'FeatureImportance': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["sub_title"], typing_extensions.Literal["visualized_items"], typing_extensions.Literal["metadata_map"], typing_extensions.Literal["guid"], typing_extensions.Literal["grads_analysis"], typing_extensions.Literal["title"], typing_extensions.Literal["type"], typing_extensions.Literal["feature_importance"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sub_title"]) -> MetaOapg.properties.sub_title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visualized_items"]) -> MetaOapg.properties.visualized_items: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata_map"]) -> MetaOapg.properties.metadata_map: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["guid"]) -> MetaOapg.properties.guid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["grads_analysis"]) -> 'GradsAnalysis': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["feature_importance"]) -> 'FeatureImportance': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["sub_title"], typing_extensions.Literal["visualized_items"], typing_extensions.Literal["metadata_map"], typing_extensions.Literal["guid"], typing_extensions.Literal["grads_analysis"], typing_extensions.Literal["title"], typing_extensions.Literal["type"], typing_extensions.Literal["feature_importance"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        sub_title: typing.Union[MetaOapg.properties.sub_title, str, ],
        visualized_items: typing.Union[MetaOapg.properties.visualized_items, list, tuple, ],
        metadata_map: typing.Union[MetaOapg.properties.metadata_map, dict, frozendict.frozendict, ],
        guid: typing.Union[MetaOapg.properties.guid, str, ],
        grads_analysis: 'GradsAnalysis',
        title: typing.Union[MetaOapg.properties.title, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        feature_importance: 'FeatureImportance',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SampleAnalysisViz':
        return super().__new__(
            cls,
            *args,
            sub_title=sub_title,
            visualized_items=visualized_items,
            metadata_map=metadata_map,
            guid=guid,
            grads_analysis=grads_analysis,
            title=title,
            type=type,
            feature_importance=feature_importance,
            _configuration=_configuration,
        )

from openapi_client.model.feature_importance import FeatureImportance
from openapi_client.model.grads_analysis import GradsAnalysis
from openapi_client.model.visualized_item import VisualizedItem



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ModelTestResultSuccess(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "queryStatus",
            "modelId",
            "succefullSamples",
            "testSucceeded",
            "allSamples",
            "aggregation",
            "epoch",
        }
        
        class properties:
            testSucceeded = schemas.BoolSchema
            modelId = schemas.StrSchema
            aggregation = schemas.Float64Schema
            succefullSamples = schemas.Float64Schema
            allSamples = schemas.Float64Schema
            epoch = schemas.Float64Schema
            
            
            class queryStatus(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "success": "SUCCESS",
                    }
                
                @schemas.classproperty
                def SUCCESS(cls):
                    return cls("success")
            __annotations__ = {
                "testSucceeded": testSucceeded,
                "modelId": modelId,
                "aggregation": aggregation,
                "succefullSamples": succefullSamples,
                "allSamples": allSamples,
                "epoch": epoch,
                "queryStatus": queryStatus,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    queryStatus: MetaOapg.properties.queryStatus
    modelId: MetaOapg.properties.modelId
    succefullSamples: MetaOapg.properties.succefullSamples
    testSucceeded: MetaOapg.properties.testSucceeded
    allSamples: MetaOapg.properties.allSamples
    aggregation: MetaOapg.properties.aggregation
    epoch: MetaOapg.properties.epoch
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["queryStatus"]) -> MetaOapg.properties.queryStatus: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["succefullSamples"]) -> MetaOapg.properties.succefullSamples: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["testSucceeded"]) -> MetaOapg.properties.testSucceeded: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allSamples"]) -> MetaOapg.properties.allSamples: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["aggregation"]) -> MetaOapg.properties.aggregation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["queryStatus"], typing_extensions.Literal["modelId"], typing_extensions.Literal["succefullSamples"], typing_extensions.Literal["testSucceeded"], typing_extensions.Literal["allSamples"], typing_extensions.Literal["aggregation"], typing_extensions.Literal["epoch"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["queryStatus"]) -> MetaOapg.properties.queryStatus: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["succefullSamples"]) -> MetaOapg.properties.succefullSamples: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["testSucceeded"]) -> MetaOapg.properties.testSucceeded: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allSamples"]) -> MetaOapg.properties.allSamples: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["aggregation"]) -> MetaOapg.properties.aggregation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["queryStatus"], typing_extensions.Literal["modelId"], typing_extensions.Literal["succefullSamples"], typing_extensions.Literal["testSucceeded"], typing_extensions.Literal["allSamples"], typing_extensions.Literal["aggregation"], typing_extensions.Literal["epoch"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        queryStatus: typing.Union[MetaOapg.properties.queryStatus, str, ],
        modelId: typing.Union[MetaOapg.properties.modelId, str, ],
        succefullSamples: typing.Union[MetaOapg.properties.succefullSamples, decimal.Decimal, int, float, ],
        testSucceeded: typing.Union[MetaOapg.properties.testSucceeded, bool, ],
        allSamples: typing.Union[MetaOapg.properties.allSamples, decimal.Decimal, int, float, ],
        aggregation: typing.Union[MetaOapg.properties.aggregation, decimal.Decimal, int, float, ],
        epoch: typing.Union[MetaOapg.properties.epoch, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ModelTestResultSuccess':
        return super().__new__(
            cls,
            *args,
            queryStatus=queryStatus,
            modelId=modelId,
            succefullSamples=succefullSamples,
            testSucceeded=testSucceeded,
            allSamples=allSamples,
            aggregation=aggregation,
            epoch=epoch,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Aggregations(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "field",
            "aggregation",
        }
        
        class properties:
            field = schemas.StrSchema
        
            @staticmethod
            def aggregation() -> typing.Type['AggregationMethod']:
                return AggregationMethod
            __annotations__ = {
                "field": field,
                "aggregation": aggregation,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    field: MetaOapg.properties.field
    aggregation: 'AggregationMethod'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["aggregation"]) -> 'AggregationMethod': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["aggregation"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["aggregation"]) -> 'AggregationMethod': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["aggregation"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        field: typing.Union[MetaOapg.properties.field, str, ],
        aggregation: 'AggregationMethod',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Aggregations':
        return super().__new__(
            cls,
            *args,
            field=field,
            aggregation=aggregation,
            _configuration=_configuration,
        )

from openapi_client.model.aggregation_method import AggregationMethod



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class CreateModelTestRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "testFilter",
            "name",
            "projectId",
        }
        
        class properties:
            projectId = schemas.StrSchema
            name = schemas.StrSchema
        
            @staticmethod
            def testFilter() -> typing.Type['ClientFilterParams']:
                return ClientFilterParams
            
            
            class datasetFilter(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ESFilter']:
                        return ESFilter
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ESFilter'], typing.List['ESFilter']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'datasetFilter':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ESFilter':
                    return super().__getitem__(i)
            __annotations__ = {
                "projectId": projectId,
                "name": name,
                "testFilter": testFilter,
                "datasetFilter": datasetFilter,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    testFilter: 'ClientFilterParams'
    name: MetaOapg.properties.name
    projectId: MetaOapg.properties.projectId
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["testFilter"]) -> 'ClientFilterParams': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["datasetFilter"]) -> MetaOapg.properties.datasetFilter: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["testFilter"], typing_extensions.Literal["name"], typing_extensions.Literal["projectId"], typing_extensions.Literal["datasetFilter"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["testFilter"]) -> 'ClientFilterParams': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["datasetFilter"]) -> typing.Union[MetaOapg.properties.datasetFilter, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["testFilter"], typing_extensions.Literal["name"], typing_extensions.Literal["projectId"], typing_extensions.Literal["datasetFilter"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        testFilter: 'ClientFilterParams',
        name: typing.Union[MetaOapg.properties.name, str, ],
        projectId: typing.Union[MetaOapg.properties.projectId, str, ],
        datasetFilter: typing.Union[MetaOapg.properties.datasetFilter, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CreateModelTestRequest':
        return super().__new__(
            cls,
            *args,
            testFilter=testFilter,
            name=name,
            projectId=projectId,
            datasetFilter=datasetFilter,
            _configuration=_configuration,
        )

from openapi_client.model.client_filter_params import ClientFilterParams
from openapi_client.model.es_filter import ESFilter
